isGaplessSupportRequired property
Constrains enablement of audio offload to happen only if the device can fulfill any gapless transitions that might exist in the playlist during offload.
Implementation
final bool isGaplessSupportRequired;
Constrains enablement of audio offload to happen only if the device can fulfill any gapless transitions that might exist in the playlist during offload.
final bool isGaplessSupportRequired;