isSpeedChangeSupportRequired property

bool isSpeedChangeSupportRequired
final

Constrains enablement of audio offload to happen only if the device can fulfill any speed change request during offload.

Implementation

final bool isSpeedChangeSupportRequired;