currentIndex property
The index of the currently playing item, or null if no item is selected.
Implementation
// TODO: Consider introducing currentAudioSourceId
final int? currentIndex;
The index of the currently playing item, or null if no item is selected.
// TODO: Consider introducing currentAudioSourceId
final int? currentIndex;