errorCode property
The error code when processingState is ProcessingState.error.
Supported on Android, iOS and web. For other platforms, check the documentation of the respective platform implementation.
Implementation
final int? errorCode;
The error code when processingState is ProcessingState.error.
Supported on Android, iOS and web. For other platforms, check the documentation of the respective platform implementation.
final int? errorCode;