AndroidAudioOffloadPreferences class
Audio offload preferences for Android.
IMPORTANT: activation of audio offload depends on a negotiation between ExoPlayer and the device to determine whether offload can be supported for a given format and with given constraints (gapless, speed change). However, several instances have been reported where the device incorrectly confirms support for audio offload when it doesn't, and this can result in buggy audio playback. Therefore, it is advised that you programmatically enable audio offload only on device/OS combinations that you have tested and verified to work.
Constructors
- AndroidAudioOffloadPreferences({AndroidAudioOffloadMode audioOffloadMode = AndroidAudioOffloadMode.disabled, bool isGaplessSupportRequired = false, bool isSpeedChangeSupportRequired = false})
-
const
Properties
- audioOffloadMode → AndroidAudioOffloadMode
-
The preferred audio offload mode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGaplessSupportRequired → bool
-
Constrains enablement of audio offload to happen only if the device
can fulfill any gapless transitions that might exist in the playlist
during offload.
final
- isSpeedChangeSupportRequired → bool
-
Constrains enablement of audio offload to happen only if the device
can fulfill any speed change request during offload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited