isSpeedChangeSupportRequired property
Constrains enablement of audio offload to happen only if the device can fulfill any speed change request during offload.
Implementation
final bool isSpeedChangeSupportRequired;
Constrains enablement of audio offload to happen only if the device can fulfill any speed change request during offload.
final bool isSpeedChangeSupportRequired;