PlayerEvent class
Encapsulates the playback event and the playing state of the player.
Constructors
- PlayerEvent({PlaybackEvent? playbackEvent, bool playing = false})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- playbackEvent → PlaybackEvent
-
The current PlaybackEvent
final
- playing → bool
-
Whether the player is currently playing.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{PlaybackEvent? playbackEvent, bool? playing}) → PlayerEvent -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override